import { onMounted, ref, watch } from "vue";

// composables/useLocalStorage.ts
export const useLocalStorage = <T>(key: string, initialValue: T) => {
    const storedValue = ref<T | null>(null);
  
    // Load value from localStorage on mount
    onMounted(() => {
      if (typeof window !== 'undefined') {
        const stored = window.localStorage.getItem(key);
        storedValue.value = stored ? JSON.parse(stored) : initialValue;
      }
    });
  
    // Watch the value and save it to localStorage when it changes
    watch(storedValue, (newValue) => {
      if (typeof window !== 'undefined') {
        window.localStorage.setItem(key, JSON.stringify(newValue));
      }
    });
  
    return storedValue;
  };
  