import Dropdown from '../../components/actions/dropdown.vue';
import { Meta, StoryFn } from '@storybook/vue3';

export default {
  title: 'Actions/Dropdown',
  component: Dropdown,
  tags: ['autodocs'],
  argTypes: {
    items: {
      control: 'object',
      description: 'Array of dropdown items with `text` and `link`.',
    },
    position: {
      control: 'select',
      options: ['left', 'right', 'bottom', 'top'],
      description: 'Controls the position of the dropdown relative to the button.',
    },
    floatPosition: {
      control: 'select',
      options: ['start', 'end'],
      description: 'Determines the float position (start or end).',
    },
    openOnHover: {
      control: 'boolean',
      description: 'If true, the dropdown opens on hover.',
    },
    forceOpen: {
      control: 'boolean',
      description: 'If true, the dropdown remains open.',
    },
  },
} as Meta<typeof Dropdown>;

const Template: StoryFn<typeof Dropdown> = (args, { slots }) => ({
  components: { Dropdown },
  setup() {
    return { args, slots };
  },
  template: `
    <Dropdown v-bind="args">
      <template #default>
        <div class="btn m-1"><button>Custom Trigger</button></div>
      </template>
      <template #additional>
        <div class="p-2 text-sm">Additional Slot Content</div>
      </template>
    </Dropdown>
  `,
});

export const Default = Template.bind({});
Default.args = {
  items: [
    { text: 'Item 1', link: '#' },
    { text: 'Item 2', link: '#' },
    { text: 'Item 3', link: '#' },
  ],
  position: 'bottom',
  floatPosition: 'start',
  openOnHover: false,
  forceOpen: false,
};
Default.parameters = {
  docs: {
    description: {
      component:
        'A dropdown component with configurable props and slots for customization. Be sure to put a button in the default slot to get the desired results!',
    },
  },
};
