import Modal from '../../components/actions/modal.vue';
import { Meta, StoryFn } from '@storybook/vue3';

export default {
  title: 'Actions/Modal',
  component: Modal,
  tags: ['autodocs'], // Added autodocs tag
  argTypes: {
    position: {
      control: 'select',
      options: ['top', 'bottom', 'center'],
      description: 'Controls the position of the modal.',
    },
    withBackdrop: {
      control: 'boolean',
      description: 'If true, a backdrop is displayed behind the modal.',
    },
  },
} as Meta<typeof Modal>;

const Template: StoryFn<typeof Modal> = (args, { slots }) => ({
  components: { Modal },
  setup() {
    return { args, slots };
  },
  template: `
    <Modal v-bind="args">
      <template #trigger>
        <button class="btn">Custom Trigger</button>
      </template>
      <template #default>
        <h2 class="text-xl font-bold">Modal Content</h2>
        <p>This is an example modal.</p>
      </template>
      <template #actions>
        <button class="btn btn-primary">Confirm</button>
      </template>
      <template #close-button>
        <button class="btn btn-secondary">Dismiss</button>
      </template>
    </Modal>
  `,
});

export const Default = Template.bind({});
Default.args = {
  position: 'center',
  withBackdrop: true,
};
Default.parameters = {
  docs: {
    description: {
      component: 'A customizable modal component with slots for trigger, content, actions, and a close button.',
    },
  },
};
