import Avatar from '../../components/data-display/avatar.vue'; // Adjust the path as per your setup
import { Meta, StoryFn } from '@storybook/vue3';

export default {
  title: 'Data Display/Avatar',
  component: Avatar,
  tags: ['autodocs'], // Include autodocs tag
  argTypes: {
    image: {
      control: 'text',
      description: 'URL of the avatar image.',
    },
    onlineStatus: {
      control: 'select',
      options: ['online', 'offline', 'none'],
      description: 'Online status of the avatar.',
    },
    initials: {
        control: "text",
        description: 'The Initials of the user'
    }
  },
} as Meta<typeof Avatar>;

const Template: StoryFn<typeof Avatar> = (args) => ({
  components: { Avatar },
  setup() {
    return { args };
  },
  template: `
    <Avatar v-bind="args" />
  `,
});

export const Default = Template.bind({});
Default.args = {
  image: 'https://randomuser.me/api/portraits/men/32.jpg', // Example image URL
  onlineStatus: "none",
  initials: "JM",
};
Default.parameters = {
  docs: {
    description: {
      component: 'An avatar component that displays an online/offline status based on the `online` prop.',
    },
  },
};

export const Online = Template.bind({});
Online.args = {
  image: 'https://randomuser.me/api/portraits/men/32.jpg', // Example image URL
  onlineStatus: "online",
  initials: "SYP",
};
Online.parameters = {
  docs: {
    description: {
      component: 'An avatar component that displays an online/offline status based on the `online` prop.',
    },
  },
};

export const Offline = Template.bind({});
Offline.args = {
  image: 'https://randomuser.me/api/portraits/men/32.jpg', // Example image URL
  onlineStatus: "offline",
  initials: 'SS'
};
Offline.parameters = {
  docs: {
    description: {
      story: 'This variant displays the avatar with an offline status.',
    },
  },
};
