import Badge from '../../components/data-display/badge.vue'; // Adjust the path as per your setup
import { Meta, StoryFn } from '@storybook/vue3';

export default {
  title: 'Data Display/Badge',
  component: Badge,
  tags: ['autodocs'], // Include autodocs tag
  argTypes: {
    color: {
      control: 'select',
      options: ['neutral', 'primary', 'secondary', 'accent', 'ghost', 'info', 'success', 'warning', 'error'],
      description: 'Sets the color of the badge.',
    },
    outline: {
      control: 'boolean',
      description: 'If true, the badge will have an outline style.',
    },
    size: {
      control: 'select',
      options: ['extra small', 'small', 'medium', 'large'],
      description: 'Sets the size of the badge.',
    },
  },
} as Meta<typeof Badge>;

const Template: StoryFn<typeof Badge> = (args) => ({
  components: { Badge },
  setup() {
    return { args };
  },
  template: `
    <Badge v-bind="args">New</Badge>
  `,
});

export const Default = Template.bind({});
Default.args = {
  color: 'primary',
  outline: false,
  size: 'medium',
};
Default.parameters = {
  docs: {
    description: {
      component: 'A customizable badge component with different colors, sizes, and outline styles.',
    },
  },
};

export const Outlined = Template.bind({});
Outlined.args = {
  color: 'success',
  outline: true,
  size: 'small',
};
Outlined.parameters = {
  docs: {
    description: {
      story: 'This variant demonstrates a badge with the outline style enabled.',
    },
  },
};

export const LargeWarning = Template.bind({});
LargeWarning.args = {
  color: 'warning',
  outline: false,
  size: 'large',
};
LargeWarning.parameters = {
  docs: {
    description: {
      story: 'This variant shows a large-sized badge with a warning color.',
    },
  },
};
