import Card from '../../components/data-display/card.vue'; // Adjust the path as per your setup
import { Meta, StoryFn } from '@storybook/vue3';

export default {
  title: 'Data Display/Card',
  component: Card,
  tags: ['autodocs'], // Include autodocs tag
  argTypes: {
    imgUrl: {
      control: 'text',
      description: 'URL of the image to display on the card.',
    },
    alt: {
      control: 'text',
      description: 'Alt text for the image.',
    },
    title: {
      control: 'text',
      description: 'Title displayed on the card.',
    },
    description: {
      control: 'text',
      description: 'Description text for the card.',
    },
    outlined: {
      control: 'boolean',
      description: 'If true, applies an outline style to the card.',
    },
  },
} as Meta<typeof Card>;

const Template: StoryFn<typeof Card> = (args) => ({
  components: { Card },
  setup() {
    return { args };
  },
  template: `
    <Card v-bind="args">
      <template #details>
        <p>This is additional content passed through the details slot.</p>
      </template>
      <template #actions>
        <button class="btn btn-primary">Action Button</button>
      </template>
    </Card>
  `,
});

export const Default = Template.bind({});
Default.args = {
  imgUrl: 'https://via.placeholder.com/300x200',
  alt: 'Placeholder image',
  title: 'Card Title',
  description: 'This is a description of the card.',
  outlined: false,
};
Default.parameters = {
  docs: {
    description: {
      component: 'A card component that can display an image, title, description, and has an optional outlined style.',
    },
  },
};

export const OutlinedCard = Template.bind({});
OutlinedCard.args = {
  imgUrl: 'https://via.placeholder.com/300x200',
  alt: 'Placeholder image',
  title: 'Outlined Card Title',
  description: 'This card has an outline style applied.',
  outlined: true,
};
OutlinedCard.parameters = {
  docs: {
    description: {
      story: 'This variant demonstrates a card with the outline style enabled.',
    },
  },
};
