import Rating from '../../components/data-input/rating.vue';
import { Meta, StoryFn } from '@storybook/vue3';

export default {
  title: 'Data Input/Rating',
  component: Rating,
  tags: ['autodocs'], // Include autodocs tag
  argTypes: {
    initialRating: {
      control: 'number',
      description: 'The initial rating value.',
    },
    numberOfStars: {
      control: 'number',
      description: 'The total number of stars to display.',
    },
    halfStars: {
      control: 'boolean',
      description: 'If true, allows half-star ratings.',
    },
    isInteractive: {
      control: 'boolean',
      description: 'If true, allows users to interact and change the rating.',
    },
    size: {
      control: 'select',
      options: ['xs', 'sm', 'md', 'lg'],
      description: 'The size of the star icons.',
    },
  },
} as Meta<typeof Rating>;

const Template: StoryFn<typeof Rating> = (args) => ({
  components: { Rating },
  setup() {
    return { args };
  },
  template: `
    <Rating v-bind="args" />
  `,
});

export const Default = Template.bind({});
Default.args = {
  initialRating: 2.5,
  numberOfStars: 5,
  halfStars: false,
  isInteractive: false,
  size: 'sm',
};
Default.parameters = {
  docs: {
    description: {
      component: 'A star rating component with options for interactivity, half-star ratings, and size customization.',
    },
  },
};

export const Interactive = Template.bind({});
Interactive.args = {
  initialRating: 3,
  numberOfStars: 5,
  halfStars: false,
  isInteractive: true,
  size: 'xs',
};
Interactive.parameters = {
  docs: {
    description: {
      story: 'This variant allows users to interact and change the rating.',
    },
  },
};
