import { defineConfig } from 'vite';
import vue from '@vitejs/plugin-vue';
import dts from 'vite-plugin-dts'
import { fileURLToPath } from 'url';
import { resolve, dirname } from 'path'
import tailwindcss from '@tailwindcss/vite';


// Handle __dirname in ESM-compatible TypeScript
const __filename = fileURLToPath(import.meta.url);
const __dirname = dirname(__filename);


// https://vite.dev/config/
export default defineConfig({
  plugins: [
    tailwindcss(),
    vue(),
    dts({
      tsconfigPath: './tsconfig.build.json',
      include: ['./src/'],
      rollupTypes: true,
    })
  ],
  build: {
    lib: {
      entry: resolve(__dirname, "src/index.ts"),
      name: "ManolisUi",
      fileName: "manolis-ui",
    },

    rollupOptions: {
      external: ['vue'],
      output: {
        globals: {
          vue: 'Vue',
        },
      },
    },
  },
  base: '/manolis-ui/',
});

